@@ -110,7 +110,7 @@ int StoredDrawParams::maxLines(int f) const
 
 const QFont& StoredDrawParams::font() const
 {
-    static QFont* f = 0;
+    static QFont* f = nullptr;
     if (!f) f = new QFont(QApplication::font());
 
     return *f;
@@ -184,8 +184,8 @@ void StoredDrawParams::setMaxLines(int f, int m)
 
 RectDrawing::RectDrawing(const QRect& r)
 {
-    _fm = 0;
-    _dp = 0;
+    _fm = nullptr;
+    _dp = nullptr;
     setRect(r);
 }
 
@@ -503,7 +503,7 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
     bool isBottom = false;
     bool isCenter = false;
     bool isRight = false;
-    int* used = 0;
+    int* used = nullptr;
     switch(pos) {
     case DrawParams::TopLeft:
         used = &_usedTopLeft;
@@ -809,7 +809,7 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
 
 TreeMapItem* TreeMapItemList::commonParent()
 {
-    if (isEmpty()) return 0;
+    if (isEmpty()) return nullptr;
 
     TreeMapItem* parent = first();
     for(int i = 1; parent && i<size(); i++)
@@ -857,8 +857,8 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value)
     _parent = parent;
 
     _sum = 0;
-    _children = 0;
-    _widget = 0;
+    _children = nullptr;
+    _widget = nullptr;
     _index = -1;
     _depth = -1; // not set
     _unused_self = 0;
@@ -889,8 +889,8 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
     setText(0, text1);
 
     _sum = 0;
-    _children = 0;
-    _widget = 0;
+    _children = nullptr;
+    _widget = nullptr;
     _index = -1;
     _depth = -1; // not set
     _unused_self = 0;
@@ -905,7 +905,7 @@ TreeMapItem::~TreeMapItem()
     if (_children) {
         qDeleteAll(*_children);
         delete _children;
-        _children = 0;
+        _children = nullptr;
     }
 
     // finally, notify widget about deletion
@@ -952,7 +952,7 @@ void TreeMapItem::clear()
 
         qDeleteAll(*_children);
         delete _children;
-        _children = 0;
+        _children = nullptr;
     }
 }
 
@@ -1009,7 +1009,7 @@ void TreeMapItem::addItem(TreeMapItem* i)
     i->setParent(this);
 
     _children->append(i); // preserve insertion order
-    if (sorting(0) != -1)
+    if (sorting(nullptr) != -1)
         std::sort(_children->begin(), _children->end(), treeMapItemLessThan);
 }
 
@@ -1206,10 +1206,10 @@ TreeMapWidget::TreeMapWidget(TreeMapItem* base,
     // _forceText will be false on resizing (per default)
 
     // start state: _selection is an empty list
-    _current = 0;
-    _oldCurrent = 0;
-    _pressed = 0;
-    _lastOver = 0;
+    _current = nullptr;
+    _oldCurrent = nullptr;
+    _pressed = nullptr;
+    _lastOver = nullptr;
     _needsRefresh = _base;
 
     setAttribute(Qt::WA_NoSystemBackground, true);
@@ -1524,10 +1524,10 @@ void TreeMapWidget::deletingItem(TreeMapItem* i)
     _selection.removeAll(i);
     _tmpSelection.removeAll(i);
 
-    if (_current == i) _current = 0;
-    if (_oldCurrent == i) _oldCurrent = 0;
-    if (_pressed == i) _pressed = 0;
-    if (_lastOver == i) _lastOver = 0;
+    if (_current == i) _current = nullptr;
+    if (_oldCurrent == i) _oldCurrent = nullptr;
+    if (_pressed == i) _pressed = nullptr;
+    if (_lastOver == i) _lastOver = nullptr;
 
     // do not redraw a deleted item
     if (_needsRefresh == i) {
@@ -1561,14 +1561,14 @@ QString TreeMapWidget::tipString(TreeMapItem* i) const
 TreeMapItem* TreeMapWidget::item(int x, int y) const
 {
 
-    if (!rect().contains(x, y)) return 0;
+    if (!rect().contains(x, y)) return nullptr;
     if (DEBUG_DRAWING) qDebug() << "item(" << x << "," << y << "):";
 
     TreeMapItem* p = _base;
     TreeMapItem* i;
     while (1) {
         TreeMapItemList* list = p->children();
-        i = 0;
+        i = nullptr;
         if (list) {
             int idx;
             for (idx=0; idx<list->size(); idx++) {
@@ -1588,11 +1588,11 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
                     break;
                 }
             }
-            if (idx == list->size()) i = 0; // not contained in child
+            if (idx == list->size()) i = nullptr; // not contained in child
         }
 
         if (!i) {
-            static TreeMapItem* last = 0;
+            static TreeMapItem* last = nullptr;
             if (p != last) {
                 last = p;
 
@@ -1607,7 +1607,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
         }
         p = i;
     }
-    return 0;
+    return nullptr;
 }
 
 TreeMapItem* TreeMapWidget::possibleSelection(TreeMapItem* i) const
@@ -1696,8 +1696,8 @@ TreeMapItemList TreeMapWidget::diff(TreeMapItemList& l1,
  */
 TreeMapItem* TreeMapWidget::setTmpSelected(TreeMapItem* item, bool selected)
 {
-    if (!item) return 0;
-    if (_selectionMode == NoSelection) return 0;
+    if (!item) return nullptr;
+    if (_selectionMode == NoSelection) return nullptr;
 
     TreeMapItemList old = _tmpSelection;
 
@@ -1736,7 +1736,7 @@ bool TreeMapWidget::clearSelection(TreeMapItem* parent)
         changed->redraw();
         emit selectionChanged();
     }
-    return (changed != 0);
+    return (changed != nullptr);
 }
 
 bool TreeMapWidget::isSelected(TreeMapItem* i) const
@@ -1802,9 +1802,9 @@ TreeMapItem* TreeMapWidget::setTmpRangeSelection(TreeMapItem* i1,
                                                  TreeMapItem* i2,
                                                  bool selected)
 {
-    if ((i1 == 0) && (i2 == 0)) return 0;
-    if ((i1 == 0) || i1->isChildOf(i2)) return setTmpSelected(i2, selected);
-    if ((i2 == 0) || i2->isChildOf(i1)) return setTmpSelected(i1, selected);
+    if ((i1 == nullptr) && (i2 == nullptr)) return nullptr;
+    if ((i1 == nullptr) || i1->isChildOf(i2)) return setTmpSelected(i2, selected);
+    if ((i2 == nullptr) || i2->isChildOf(i1)) return setTmpSelected(i1, selected);
 
     TreeMapItem* changed = setTmpSelected(i1, selected);
     TreeMapItem* changed2 = setTmpSelected(i2, selected);
@@ -1870,7 +1870,7 @@ void TreeMapWidget::mousePressEvent( QMouseEvent* e )
     _inControlDrag = e->modifiers() & Qt::ControlModifier;
     _lastOver = _pressed;
 
-    TreeMapItem* changed = 0;
+    TreeMapItem* changed = nullptr;
     TreeMapItem* item = possibleSelection(_pressed);
 
     switch(_selectionMode) {
@@ -1918,8 +1918,8 @@ void TreeMapWidget::mousePressEvent( QMouseEvent* e )
                 emit selectionChanged(_lastOver);
             emit selectionChanged();
         }
-        _pressed = 0;
-        _lastOver = 0;
+        _pressed = nullptr;
+        _lastOver = nullptr;
         emit rightButtonPressed(i, e->pos());
     }
 }
@@ -1933,12 +1933,12 @@ void TreeMapWidget::mouseMoveEvent( QMouseEvent* e )
     if (_lastOver == over) return;
 
     setCurrent(over);
-    if (over == 0) {
-        _lastOver = 0;
+    if (over == nullptr) {
+        _lastOver = nullptr;
         return;
     }
 
-    TreeMapItem* changed = 0;
+    TreeMapItem* changed = nullptr;
     TreeMapItem* item = possibleSelection(over);
 
     switch(_selectionMode) {
@@ -1992,8 +1992,8 @@ void TreeMapWidget::mouseReleaseEvent( QMouseEvent* )
             emit clicked(_lastOver);
     }
 
-    _pressed = 0;
-    _lastOver = 0;
+    _pressed = nullptr;
+    _lastOver = nullptr;
 }
 
 
@@ -2057,8 +2057,8 @@ void TreeMapWidget::keyPressEvent( QKeyEvent* e )
             if (changed)
                 redraw(changed);
         }
-        _pressed = 0;
-        _lastOver = 0;
+        _pressed = nullptr;
+        _lastOver = nullptr;
     }
 
     if ((e->key() == Qt::Key_Space) ||
@@ -2229,7 +2229,7 @@ void TreeMapWidget::drawTreeMap()
         _fontHeight = fontMetrics().height();
 
         drawItems(&p, _needsRefresh);
-        _needsRefresh = 0;
+        _needsRefresh = nullptr;
     }
 
     QPainter p(this);
@@ -2536,7 +2536,7 @@ void TreeMapWidget::drawItems(QPainter* p,
             QRect firstRect = QRect(r.x(), r.y(), nextPos, r.height());
 
             if (nextPos < _visibleWidth) {
-                if (item->sorting(0) == -1) {
+                if (item->sorting(nullptr) == -1) {
                     // fill current rect with hash pattern
                     drawFill(item, p, firstRect);
                 }
@@ -2555,7 +2555,7 @@ void TreeMapWidget::drawItems(QPainter* p,
             len = lenLeft;
 
             if (!drawDetails) {
-                if (item->sorting(0) == -1)
+                if (item->sorting(nullptr) == -1)
                     drawDetails = true;
                 else {
                     drawFill(item, p, r, list, idx, len, goBack);
@@ -2587,7 +2587,7 @@ void TreeMapWidget::drawItems(QPainter* p,
             QRect firstRect = QRect(r.x(), r.y(), r.width(), nextPos);
 
             if (nextPos < _visibleWidth) {
-                if (item->sorting(0) == -1) {
+                if (item->sorting(nullptr) == -1) {
                     drawFill(item, p, firstRect);
                 }
                 else {
@@ -2604,7 +2604,7 @@ void TreeMapWidget::drawItems(QPainter* p,
             len = lenLeft;
 
             if (!drawDetails) {
-                if (item->sorting(0) == -1)
+                if (item->sorting(nullptr) == -1)
                     drawDetails = true;
                 else {
                     drawFill(item, p, r, list, idx, len, goBack);
@@ -2716,7 +2716,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
         }
 
         // if no sorting, do not stop drawing
-        if (item->sorting(0) == -1) drawOn = true;
+        if (item->sorting(nullptr) == -1) drawOn = true;
 
         // second half
         if (drawOn)
@@ -2771,7 +2771,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
         int nextPos = (user_sum <= 0.0) ? 0: (int)(lastPos * val / user_sum +.5);
         if (nextPos>lastPos) nextPos = lastPos;
 
-        if ((item->sorting(0) != -1) && (nextPos < _visibleWidth)) {
+        if ((item->sorting(nullptr) != -1) && (nextPos < _visibleWidth)) {
             drawFill(item, p, fullRect, list, idx, len, goBack);
             if (DEBUG_DRAWING)
                 qDebug() << " -drawItemArray(" << item->path(0).join(QStringLiteral("/"))
